﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Net.NetworkInformation;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectAirplaneWithRadar
{
    public class DrawningAirplaneWithRadar
    {
        public EntityAirplaneWithRadar? EntityAirplaneWithRadar { get; private set; }
        public int _pictureWidth;
        public int _pictureHeight;
        public int _startPosX;
        public int _startPosY;
        private readonly int _airplaneWidth = 200;
        private readonly int _airplaneHeight = 78;
        public bool Init(int speed, double weight, Color bodyColor, Color additionalColor, bool radar, bool dopbak, int width, int height)
        {
            _pictureWidth = width;
            _pictureHeight = height;
            if (_airplaneWidth > _pictureWidth || _airplaneHeight > _pictureHeight)
                return false;
            EntityAirplaneWithRadar = new EntityAirplaneWithRadar();
            EntityAirplaneWithRadar.Init(speed, weight, bodyColor, additionalColor, radar, dopbak);
            return true;
        }
        public void SetPosition(int x, int y)
        {   
            if(x < 0 || y < 0 ||x+_airplaneWidth >= _pictureWidth|| y + _airplaneHeight >= _pictureHeight)
            {
                x = y = 10;
                _startPosX = x;
                _startPosY=y;
            }                    
            _startPosX = x;
            _startPosY = y;
        }
        public void MoveTransport(Direction direction)
        {
            if (EntityAirplaneWithRadar == null)
            {
                return;
            }
            switch (direction)
            {
                case Direction.Left:
                    if (_startPosX - EntityAirplaneWithRadar.Step > 0)
                    {
                        _startPosX -= (int)EntityAirplaneWithRadar.Step;
                    }
                    break;
                case Direction.Up:
                    if (_startPosY - EntityAirplaneWithRadar.Step > 0)
                    {
                        _startPosY -= (int)EntityAirplaneWithRadar.Step;
                    }
                    break;
                case Direction.Right:
                    if (_startPosX + EntityAirplaneWithRadar.Step+_airplaneWidth < _pictureWidth) 
                    {
                        _startPosX += (int)EntityAirplaneWithRadar.Step;
                    }
                    break;
                case Direction.Down:
                    if (_startPosY + EntityAirplaneWithRadar.Step+_airplaneHeight < _pictureHeight) 
                    {
                        _startPosY += (int)EntityAirplaneWithRadar.Step;
                    }
                    break;
            }
        }
        public void DrawTransport(Graphics g)
        {
            if(EntityAirplaneWithRadar == null)
            {
                return;
            }
            Pen pen = new Pen(Color.Black, 3);
            Brush additionalBrush = new SolidBrush(EntityAirplaneWithRadar.AdditionalColor);
            // корпус
            Brush br = new SolidBrush(EntityAirplaneWithRadar.BodyColor);
            g.DrawEllipse(pen, _startPosX, _startPosY+25,180, 30) ;
            g.FillEllipse(br, _startPosX, _startPosY+25, 180, 30);
            // крыло
            Brush blackBrush = new SolidBrush(Color.Black);          
            g.FillEllipse(blackBrush, _startPosX + 70, _startPosY + 35, 80, 10);
            // стекла
            Pen blackPen = new Pen(Color.Black, 2);
            Brush blueBrush = new SolidBrush(Color.LightBlue);
            Point point1 = new Point(_startPosX+170, _startPosY+30);
            Point point2 = new Point(_startPosX+200, _startPosY+40);
            Point point3 = new Point(_startPosX+170, _startPosY + 50);
            Point[] curvePoints =
             {
                 point1,
                 point2,
                 point3,
             };
            g.FillPolygon(blueBrush, curvePoints);
            g.DrawPolygon(blackPen, curvePoints);
            g.DrawLine(blackPen, _startPosX + 170, _startPosY + 40, _startPosX + 200, _startPosY + 40);
            // хвост
            Point point4 = new Point(_startPosX, _startPosY + 35);
            Point point5 = new Point(_startPosX, _startPosY +5 );
            Point point6 = new Point(_startPosX + 30, _startPosY + 35);
            Point[] curvePoints2 =
             {
                 point4,
                 point5,
                 point6,
             };
            g.FillPolygon(br, curvePoints2);
            g.DrawPolygon(blackPen, curvePoints2);
            // шасси
            g.DrawLine(blackPen, _startPosX + 50, _startPosY + 55, _startPosX + 50, _startPosY + 70);
            g.DrawLine(blackPen, _startPosX + 150, _startPosY + 51, _startPosX + 150, _startPosY + 70);
            g.FillEllipse(blackBrush, _startPosX + 40, _startPosY + 65, 10, 10);
            g.FillEllipse(blackBrush, _startPosX + 50, _startPosY + 65, 10, 10);
            g.FillEllipse(blackBrush, _startPosX + 145, _startPosY + 65, 10, 10);
            if (EntityAirplaneWithRadar.DopBak)
            {
                //бак
                g.FillEllipse(additionalBrush, _startPosX, _startPosY + 45, 40, 20);
                g.DrawEllipse(blackPen, _startPosX, _startPosY + 45, 40, 20);
            }
            if (EntityAirplaneWithRadar.Radar)
            {
                //радар
                g.DrawLine(blackPen, _startPosX + 60, _startPosY + 25, _startPosX + 60, _startPosY + 15);
                g.DrawLine(blackPen, _startPosX + 60, _startPosY + 15, _startPosX + 67, _startPosY + 11);
                Point point7 = new Point(_startPosX + 60, _startPosY + 15);
                Point point8 = new Point(_startPosX + 60, _startPosY + 5);
                Point point9 = new Point(_startPosX + 70, _startPosY + 25);
                Point[] curvePoints3 =
                 {
                 point7,
                 point8,
                 point9,
             };
                g.FillPolygon(additionalBrush, curvePoints3);
            }
        }
    }
}
